@@ -59,9 +59,13 @@ class _Method(object):
         if self._password is not None:
             request['password'] = _encrypt_password(self._password)
 
+        if request['method'] == '__getfile__':
+            return self.call(json.dumps(request))
+
         resp = self.call(json.dumps(request))
         if resp is None:
             raise Exception('Server response is None')
+        resp = json.loads(resp.decode())
         if resp['id'] != request['id']:
             raise Exception('Inconsistent JSON request id returned')
         if resp['error'] is not None:
@@ -165,7 +169,7 @@ class ServerProxy(object):
         except socket.error:
             raise NetworkSocketException
         if response.status == 200:
-            return json.loads(response.read().decode())
+            return response.read()
         elif response.status == 400:
             raise BadRequestException(response.read().decode())
         elif response.status == 401:
@@ -182,10 +186,7 @@ class ServerProxy(object):
             raise Exception('HTTP Status %s'%response.status)
 
     def __repr__(self):
-        return (
-            "<ServerProxy for %s%s>" %
-            (self.__host, self.__handler)
-            )
+        return "<ServerProxy for %s%s>" %(self.__host, self.__handler)
 
     __str__ = __repr__
 
@@ -193,7 +194,6 @@ class ServerProxy(object):
         # magic method dispatcher
         return _Method(self._request, name, self._username, self._password)
 
-
 ################# batch calls vvv
 
 class _BatchMethod(object):
@@ -256,7 +256,7 @@ class BatchCall(object):
         req += ', '.join(str(q) for q in self._queue)
         req += ']'
 
-        response = self._server._request(req)
+        response = json.loads(self._server._request(req).decode())
 
         result = []
         for i,r in enumerate(response):
