@@ -86,31 +86,42 @@ class AuthRPCApp(object):
             except KeyError as e:
                 raise exc.HTTPBadRequest("JSON body missing parameter: %s" % e)
             self._check_auth(username, password, req.user_agent, id)
+
+            if method == '__getfile__':
+                try:
+                    with open(params[0],'rb') as f:
+                        body = f.read()
+                except IOError:
+                    raise exc.HTTPNotFound('File not found: %s'%params[0])
+                return Response(content_type='application/octet-stream',
+                                body=body)
+
             result = self._process_single(method, params, id)
 
         return Response(content_type='application/json',
                         body=dumps(result).encode())
 
     def _check_auth(self, username, password, user_agent, id=None):
-        if self.auth is not None:
-            try:
-                auth_result = self.auth(username, password, user_agent)
-            except:
-                text = traceback.format_exc()
-                exc_value = sys.exc_info()[1]
-                error_value = dict(
-                    name='JSONRPCError',
-                    code=100,
-                    message=str(exc_value),
-                    error=text)
-                return Response(
-                    status=500,
-                    content_type='application/json',
-                    body=dumps(dict(result=None,
-                                    error=error_value,
-                                    id=id)))
-            if not auth_result:
-                raise exc.HTTPUnauthorized()
+        if self.auth is None:
+            return
+        try:
+            auth_result = self.auth(username, password, user_agent)
+        except:
+            text = traceback.format_exc()
+            exc_value = sys.exc_info()[1]
+            error_value = dict(
+                name='JSONRPCError',
+                code=100,
+                message=str(exc_value),
+                error=text)
+            return Response(
+                status=500,
+                content_type='application/json',
+                body=dumps(dict(result=None,
+                                error=error_value,
+                                id=id)))
+        if not auth_result:
+            raise exc.HTTPUnauthorized()
 
     def _process_single(self, method, params, id):
         retval = {}
@@ -130,7 +141,7 @@ class AuthRPCApp(object):
                    break
         elif method.startswith('%s.'%self.obj.__class__.__name__):
             method = method.replace('%s.'%self.obj.__class__.__name__,'',1)
-        if method.startswith('_'):
+        if method.startswith('_') and method != '__getfile__':
             retval['error'] = 'Bad method name %s: must not start with _' % method
             return retval
         try:
