@@ -156,6 +156,29 @@ class ProtocolErrorTest(AuthRPCTests):
         with self.assertRaises(ProtocolError):
             self.client.api.test(1, '2', three=3)
 
+class FileTest(AuthRPCTests):
+    def runTest(self):
+        filename = 'LICENCE.txt' 
+        with open(filename,'rb') as f:
+            source = f.read()
+        self.assertEqual(self.client.__getfile__(filename), source)
+
+class NonExistentFileTest(AuthRPCTests):
+    def runTest(self):
+        from client import NotFoundException
+        with self.assertRaises(NotFoundException):
+            self.client.__getfile__('nonexistant.file')
+
+class BadAuthFileTest(unittest.TestCase):
+    def runTest(self):
+        from client import ServerProxy, UnauthorisedException
+        self.client = ServerProxy('http://localhost:1337/',
+                                  username='testuser',
+                                  password='s3cr3t',
+                                  user_agent='InternetExploiter')
+        with self.assertRaises(UnauthorisedException):
+            self.client.__getfile__('LICENCE.txt')
+
 class BatchTest(AuthRPCTests):
     def runTest(self):
         from client import BatchCall
@@ -205,6 +228,9 @@ def suite():
     suite.addTest(AddTest())
     suite.addTest(ReturnNothing())
     suite.addTest(ProtocolErrorTest())
+    suite.addTest(FileTest())
+    suite.addTest(NonExistentFileTest())
+    suite.addTest(BadAuthFileTest())
     suite.addTest(BatchTest())
     suite.addTest(SetFinishedFlag())
     suite.addTest(BadBatchTest())
